aboutsummaryrefslogtreecommitdiffstats
path: root/packages/meshbay-hub/src/meshbay_hub/static/platform.js
diff options
context:
space:
mode:
Diffstat (limited to 'packages/meshbay-hub/src/meshbay_hub/static/platform.js')
-rw-r--r--packages/meshbay-hub/src/meshbay_hub/static/platform.js17
1 files changed, 14 insertions, 3 deletions
diff --git a/packages/meshbay-hub/src/meshbay_hub/static/platform.js b/packages/meshbay-hub/src/meshbay_hub/static/platform.js
index 1715d5f..148b2eb 100644
--- a/packages/meshbay-hub/src/meshbay_hub/static/platform.js
+++ b/packages/meshbay-hub/src/meshbay_hub/static/platform.js
@@ -256,9 +256,20 @@ export const photoSync = {
};
/**
- * Backing up one kind of this phone's data (the contacts) to a group of
- * which the person is the only member (docs/MESHBAY_DESIGN.md §9.13). Android
- * only, like `photoSync`. See phone-sync.js.
+ * Where every backup of this phone goes: one folder of a group the account
+ * owns and is alone in (docs/MESHBAY_DESIGN.md §9.12). Android only, like
+ * `photoSync`. See sync-destination.js.
+ */
+export const phoneSync = {
+ available: Boolean(bridge && bridge.phoneSync),
+ destination() { return bridge.phoneSync.destination(); },
+ setDestination(d) { return bridge.phoneSync.setDestination(d); },
+};
+
+/**
+ * Backing up one kind of this phone's data (the contacts) to the destination
+ * every kind shares (docs/MESHBAY_DESIGN.md §9.13). Android only, like
+ * `photoSync`. See phone-sync.js.
*/
function docSync(name) {
const b = bridge && bridge[name];